<?php
/*
 * Plugin Name: Advanced Order Export  - Sales/Taxes (for last month)
 * Description: Sales/Taxes report (for last month)  can be exported as XLS 
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class Woe_Report_LastMonth {
    function __construct() {
		//add checkbox above buttons
		add_action("woe_settings_above_buttons", function ($settings){
			$selected = !empty($settings[ 'report_last_month' ]) ? 'checked': '';
			echo '<br><br>
			<input type=hidden name="settings[report_last_month]" value="0">
			<input type=checkbox name="settings[report_last_month]" value="1" '. $selected .'>
			Send Sales/Taxes report (for last month)<br>Preview doesn\'t work<br>';
		});
		
		//activate hooks only when export starts
		add_filter('woe_settings_validate_defaults', function ($settings) {
			if( !empty($settings['report_last_month']) ) {
				$settings['skip_empty_file'] = 0;
				$settings['from_date'] = date("Y-m-d");
				add_filter("woe_xls_header_filter", "__return_false" );
				add_filter("woe_xls_output_filter", function($row, $builder) { return false; }, 10, 2);
				add_filter("woe_xls_print_footer", array($this,"woe_xls_print_footer"), 10, 2 );
			}	
			return $settings;
		} );        
    }

    function output_header($title,$data) {
		$this->line = 1;
		$this->objPHPExcel->getActiveSheet()->setTitle( $title );
		foreach ( $data as $pos => $text ) {
			$this->objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow( $pos, $this->line, $text );
		}
		//make first bold
		$last_column = $this->objPHPExcel->getActiveSheet()->getHighestDataColumn();
		$this->objPHPExcel->getActiveSheet()->getStyle( "A1:" . $last_column . "1" )->getFont()->setBold( true );
		$this->line++;
    }
    
    function output_rec($row) {
		$pos = 0;
		foreach ( $row as $field => $text ) {
			$this->objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow( $pos, $this->line,$text );
			$pos++;
		}
		$this->line++;
    }
    function adjust_sheet() {
		try {
			$sheet        = $this->objPHPExcel->getActiveSheet();
			$cellIterator = $sheet->getRowIterator()->current()->getCellIterator();
			$cellIterator->setIterateOnlyExistingCells( true );
			foreach ( $cellIterator as $cell ) {
				$sheet->getColumnDimension( $cell->getColumn() )->setAutoSize( true );
			}
			$sheet->calculateColumnWidths();
		} catch ( Exception $e ) {
			//do nothing here , adjustment failed gracefully
		}
    }
    
	function woe_xls_print_footer($objPHPExcel,$formatter) {
		include_once( WP_PLUGIN_DIR . '/woocommerce/includes/admin/reports/class-wc-admin-report.php');
		include_once( WP_PLUGIN_DIR . '/woocommerce/includes/admin/reports/class-wc-report-taxes-by-date.php');	
		include_once( WP_PLUGIN_DIR . '/woocommerce/includes/admin/reports/class-wc-report-sales-by-date.php');	
		
		include_once( __DIR__. '/class-woe-wc-report-taxes-by-date.php');	
		include_once( __DIR__. '/class-woe-wc-report-sales-by-date.php');	
		
		$this->objPHPExcel = $objPHPExcel;

		//Rename Sheet 
		$this->output_header("Sales",array("Date","Number of items sold","Number of orders","Average net sales amount","Coupon amount","Shipping amount","Gross sales amount","Net sales amount","Refund amount") );
		//Calc
		$report = new WOE_WC_Report_Sales_By_Date();
		$report->calculate_current_range('last_month');
		$report_data = $report->get_report_data();
		$sales_rows = $report->get_main_chart();
		//print 
		$first_pos =true;
		foreach($sales_rows['order_item_counts'] as $date=>$value) {
			$rec = array();
			$rec[] = date_i18n( get_option( 'date_format' ), $date/1000 );
			$rec[] = $value[1];
			$rec[] = $sales_rows['order_counts'][$date][1];
			if($first_pos ) {
				$rec[] = $report_data->average_sales;
				$first_pos = false;
			}	
			else	
				$rec[] = "";
			$rec[] = $sales_rows['coupon_amounts'][$date][1];
			$rec[] = $sales_rows['shipping_amounts'][$date][1];
			$rec[] = $sales_rows['gross_order_amounts'][$date][1];
			$rec[] = $sales_rows['net_order_amounts'][$date][1];
			$rec[] = $sales_rows['refund_amounts'][$date][1];
			$this->output_rec($rec);
		}
		$this->adjust_sheet();
		
		//Add sheet 
		$this->objPHPExcel->createSheet(1);
		$this->objPHPExcel->setActiveSheetIndex(1);
		//Calc
		$report = new WOE_WC_Report_Taxes_By_Date();
		$report->calculate_current_range('last_month');
		$tax_rows = $report->get_main_chart();
		$summary = array("Totals",0,0,0,0,0);
		//print 
		$this->output_header("Taxes",array("Period","Number of orders","Total sales ","Total shipping ","Total tax ","Net profit") );
		foreach ( $tax_rows as $date => $tax_row ) {
			$gross     = $tax_row->total_sales - $tax_row->total_shipping;
			$total_tax = $tax_row->tax_amount + $tax_row->shipping_tax_amount;
			$rec = array();
			$rec[] = date_i18n( get_option( 'date_format' ), strtotime( $date ) );
			$rec[] = $tax_row->total_orders; 
			$rec[] = $gross;
			$rec[] = $tax_row->total_shipping;
			$rec[] = $total_tax;
			$rec[] = $gross - $total_tax;
			$this->output_rec($rec);
			$summary[1] += $tax_row->total_orders; 
			$summary[2] += $gross;
			$summary[3] += $tax_row->total_shipping;
			$summary[4] += $total_tax;
			$summary[5] += $gross - $total_tax;
		}
		$this->output_rec($summary);
		$this->adjust_sheet();
		
		//back to first 
		$this->objPHPExcel->setActiveSheetIndex(0);
	}    

}
new Woe_Report_LastMonth();